pub struct OAuthAuthorizationFlow { /* private fields */ }Expand description
Reusable OAuth authorization-code state machine and token provider.
Build this type with OAuthAuthorizationFlow::builder, call
authorize for a fully driven flow or
begin for explicit pending/authorized states, then install
the same value as both TokenProvider and OAuthScopeEscalationHandler.
Implementations
Sourceimpl OAuthAuthorizationFlow
impl OAuthAuthorizationFlow
Sourcepub fn builder(resource_url: impl Into<String>) -> OAuthAuthorizationFlowBuilder
pub fn builder(resource_url: impl Into<String>) -> OAuthAuthorizationFlowBuilder
Begin building a state machine for resource_url.
Sourcepub async fn begin<I, S>(
&self,
scopes: I,
) -> Result<OAuthAuthorizationStart, OAuthClientError>
pub async fn begin<I, S>( &self, scopes: I, ) -> Result<OAuthAuthorizationStart, OAuthClientError>
Discover, register, restore or create authorization state, and return the next explicit state.
Drive a complete authorization using the configured
OAuthAuthorizationHandler.
Sourcepub async fn complete_callback_url(
&self,
callback_url: &str,
) -> Result<(), OAuthClientError>
pub async fn complete_callback_url( &self, callback_url: &str, ) -> Result<(), OAuthClientError>
Resume a persisted authorization attempt from a callback URL.
Return the currently authorized scope set, if any.