pub struct OAuthPendingAuthorization { /* private fields */ }Expand description
An authorization attempt waiting for a callback.
Implementations
Sourceimpl OAuthPendingAuthorization
impl OAuthPendingAuthorization
Sourcepub fn request(&self) -> &OAuthAuthorizationRequest
pub fn request(&self) -> &OAuthAuthorizationRequest
Authorization request to present to a user agent or headless harness.
Sourcepub async fn complete_callback_url(
self,
callback_url: &str,
) -> Result<(), OAuthClientError>
pub async fn complete_callback_url( self, callback_url: &str, ) -> Result<(), OAuthClientError>
Complete this attempt with the callback URL returned by the AS.
Sourcepub async fn wait_for_callback(self) -> Result<(), OAuthClientError>
pub async fn wait_for_callback(self) -> Result<(), OAuthClientError>
Wait for a configured loopback redirect and complete the attempt.
Sourcepub async fn wait_for_callback_with_timeout(
self,
timeout: Duration,
) -> Result<(), OAuthClientError>
pub async fn wait_for_callback_with_timeout( self, timeout: Duration, ) -> Result<(), OAuthClientError>
Wait for a loopback redirect with a custom timeout.