OAuthClientRegistrationStore

Trait OAuthClientRegistrationStore 

pub trait OAuthClientRegistrationStore: Send + Sync {
    // Required methods
    fn load<'life0, 'life1, 'async_trait>(
        &'life0 self,
        issuer: &'life1 str,
    ) -> Pin<Box<dyn Future<Output = Result<Option<OAuthClientRegistration>, OAuthClientError>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait;
    fn save<'life0, 'life1, 'life2, 'async_trait>(
        &'life0 self,
        issuer: &'life1 str,
        registration: &'life2 OAuthClientRegistration,
    ) -> Pin<Box<dyn Future<Output = Result<(), OAuthClientError>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait,
             'life2: 'async_trait;
    fn remove<'life0, 'life1, 'async_trait>(
        &'life0 self,
        issuer: &'life1 str,
    ) -> Pin<Box<dyn Future<Output = Result<(), OAuthClientError>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait;
}
Persistent storage for issuer-bound OAuth client registrations.

Implementations must use the exact validated authorization-server issuer string as the key. They must also protect client secrets at rest using an appropriate platform secret store or equivalent controls.

Only pre-registered and dynamically registered credentials are issuer-bound. Client ID Metadata Document URLs are portable and are not passed to this store by resolve_oauth_client_registration_with_store.

Required Methods

fn load<'life0, 'life1, 'async_trait>( &'life0 self, issuer: &'life1 str, ) -> Pin<Box<dyn Future<Output = Result<Option<OAuthClientRegistration>, OAuthClientError>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

Load client credentials registered with issuer.

fn save<'life0, 'life1, 'life2, 'async_trait>( &'life0 self, issuer: &'life1 str, registration: &'life2 OAuthClientRegistration, ) -> Pin<Box<dyn Future<Output = Result<(), OAuthClientError>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait, 'life2: 'async_trait,

Save client credentials under their exact authorization-server issuer.

fn remove<'life0, 'life1, 'async_trait>( &'life0 self, issuer: &'life1 str, ) -> Pin<Box<dyn Future<Output = Result<(), OAuthClientError>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

Remove client credentials for an authorization-server issuer.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors