OAuthHttpClient

Trait OAuthHttpClient 

pub trait OAuthHttpClient:
    Send
    + Sync
    + 'static {
    // Required method
    fn execute<'life0, 'async_trait>(
        &'life0 self,
        request: OAuthHttpRequest,
    ) -> Pin<Box<dyn Future<Output = Result<OAuthHttpResponse, OAuthClientError>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
}
Application-supplied HTTP abstraction for OAuth protocol traffic.

Implementations control proxying, TLS, telemetry, retries, and test behavior without requiring the authorization state machine to depend on a particular HTTP stack.

Required Methods

fn execute<'life0, 'async_trait>( &'life0 self, request: OAuthHttpRequest, ) -> Pin<Box<dyn Future<Output = Result<OAuthHttpResponse, OAuthClientError>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Execute one OAuth protocol request.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors