#[non_exhaustive]pub enum SamplingContentOrArray {
Single(SamplingContent),
Array(Vec<SamplingContent>),
}Expand description
Content that can be either a single item or an array
The MCP spec allows content fields to be either a single SamplingContent or an array of SamplingContent items.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Implementations
Sourceimpl SamplingContentOrArray
impl SamplingContentOrArray
Sourcepub fn items(&self) -> Vec<&SamplingContent>
pub fn items(&self) -> Vec<&SamplingContent>
Get content items as a slice
Sourcepub fn into_items(self) -> Vec<SamplingContent>
pub fn into_items(self) -> Vec<SamplingContent>
Get owned content items