#[non_exhaustive]pub enum TaskSupportMode {
Required,
Optional,
Forbidden,
}Expand description
Task support mode for tool execution
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Required
Task execution is required.
Legacy clients must include task parameters. On the final protocol the server creates a task whenever the extension is negotiated, and rejects clients that did not declare it.
Optional
Task execution is optional.
Legacy clients choose by including task parameters. On the final protocol this is server policy: the router creates a task when both peers negotiated the extension and otherwise completes synchronously.
Forbidden
Task execution is forbidden; the tool always completes synchronously.