#[non_exhaustive]pub enum ProtectedResourceMetadataError {
InvalidResourceUrl(ParseError),
UnsupportedResourceScheme(String),
ResourceHasFragment,
MissingAuthorizationServer,
InvalidAuthorizationServerUrl {
url: String,
source: ParseError,
},
UnsupportedAuthorizationServerScheme(String),
}Expand description
Errors returned when validating MCP Protected Resource Metadata.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidResourceUrl(ParseError)
The resource identifier is not a valid absolute URL.
UnsupportedResourceScheme(String)
MCP HTTP resource identifiers must use HTTP or HTTPS.
ResourceHasFragment
Resource identifiers cannot contain URL fragments.
MissingAuthorizationServer
MCP Protected Resource Metadata must advertise an authorization server.
InvalidAuthorizationServerUrl
An advertised authorization-server issuer is not a valid absolute URL.
UnsupportedAuthorizationServerScheme(String)
An advertised authorization-server issuer does not use HTTP(S).