pub struct ScopeRequirement { /* private fields */ }Expand description
A set of required OAuth scopes for an operation.
All scopes in the requirement must be present in the token for access to be granted (AND semantics).
Implementations
Sourceimpl ScopeRequirement
impl ScopeRequirement
Sourcepub fn all(scopes: impl IntoIterator<Item = impl Into<String>>) -> Self
pub fn all(scopes: impl IntoIterator<Item = impl Into<String>>) -> Self
Create a scope requirement from multiple scopes.
Sourcepub fn require(self, scope: impl Into<String>) -> Self
pub fn require(self, scope: impl Into<String>) -> Self
Add a required scope to this requirement.
Sourcepub fn check(&self, claims: &TokenClaims) -> Result<(), OAuthError>
pub fn check(&self, claims: &TokenClaims) -> Result<(), OAuthError>
Check if the given token claims satisfy this requirement.
Returns Ok(()) if all required scopes are present, or
Err(OAuthError::InsufficientScope) with details about
which scopes are missing.
Sourcepub fn check_with(
&self,
claims: &TokenClaims,
matcher: &dyn ScopeMatcher,
) -> Result<(), OAuthError>
pub fn check_with( &self, claims: &TokenClaims, matcher: &dyn ScopeMatcher, ) -> Result<(), OAuthError>
Check the requirement using a custom scope matcher.
Sourcepub fn required_scopes(&self) -> &HashSet<String>
pub fn required_scopes(&self) -> &HashSet<String>
Returns the required scopes.