pub enum AddBackendError {
DuplicateNamespace(String),
AmbiguousPrefix {
new_namespace: String,
existing_namespace: String,
},
Connect(Error),
Initialize(Error),
}Expand description
Error returned when adding a dynamic backend fails.
Variants
DuplicateNamespace(String)
The namespace is already in use by an existing backend.
AmbiguousPrefix
The namespace would create an ambiguous prefix with an existing backend.
Fields
Connect(Error)
Failed to connect the transport.
Initialize(Error)
Failed during MCP initialization handshake.