pub struct Root {
pub uri: String,
pub name: Option<String>,
pub meta: Option<Value>,
}Expand description
Represents a root directory or file that the server can operate on.
Roots allow clients to expose filesystem roots to servers, enabling:
- Scoped file access
- Workspace awareness
- Security boundaries
Example
use tower_mcp_types::protocol::Root;
let root = Root::new("file:///home/user/project");
assert_eq!(root.uri, "file:///home/user/project");
assert!(root.name.is_none());
let root = Root::with_name("file:///workspace", "My Project");
assert_eq!(root.name.unwrap(), "My Project");Fields
uri: StringThe URI identifying the root. Must start with file:// for now.
name: Option<String>Optional human-readable name for the root
meta: Option<Value>Optional protocol-level metadata
Implementations