pub struct TaskPreparation { /* private fields */ }Expand description
Metadata and application state produced before task execution begins.
Implementations
Sourceimpl TaskPreparation
impl TaskPreparation
Sourcepub fn with_meta(self, meta: Map<String, Value>) -> Self
pub fn with_meta(self, meta: Map<String, Value>) -> Self
Attach protocol _meta to every view of this task.
Sourcepub fn with_extension<T: Send + Sync + 'static>(self, value: T) -> Self
pub fn with_extension<T: Send + Sync + 'static>(self, value: T) -> Self
Make application state available to the background handler through
crate::extract::Extension.