pub type InputRequests = BTreeMap<String, InputRequest>;Expand description
Map of server-initiated requests the client must fulfil, keyed by server-assigned identifiers (SEP-2322).
Aliased Type
pub struct InputRequests { /* private fields */ }pub type InputRequests = BTreeMap<String, InputRequest>;Map of server-initiated requests the client must fulfil, keyed by server-assigned identifiers (SEP-2322).
pub struct InputRequests { /* private fields */ }